@@ -14,6 +14,7 @@
 #include <QtGui/QCheckBox>
 #include <QtGui/QGroupBox>
 #include <QtGui/QHBoxLayout>
+#include <QtGui/QHeaderView>
 #include <QtGui/QKeyEvent>
 #include <QtGui/QLabel>
 #include <QtGui/QPushButton>
@@ -132,6 +133,7 @@ ModulesDialog::ModulesDialog(QWidget *parent)
 	QStringList headers;
 	headers << tr("Module name") << tr("Version") << tr("Module type") << tr("State");
 	lv_modules->setHeaderLabels(headers);
+	lv_modules->header()->setResizeMode(QHeaderView::Stretch);
 	lv_modules->setSortingEnabled(true);
 	lv_modules->setAllColumnsShowFocus(true);
 	lv_modules->setIndentation(false);
@@ -139,6 +141,7 @@ ModulesDialog::ModulesDialog(QWidget *parent)
 	lv_modules->setAlternatingRowColors(true);
 	// end our QListView
 
+#ifndef Q_WS_HILDON
 	//our QVGroupBox
 	QGroupBox *vgb_info = new QGroupBox(center);
 	QVBoxLayout *infoLayout = new QVBoxLayout(vgb_info);
@@ -149,10 +152,11 @@ ModulesDialog::ModulesDialog(QWidget *parent)
 	l_moduleinfo->setText(tr("<b>Module:</b><br/><b>Depends on:</b><br/><b>Conflicts with:</b><br/><b>Provides:</b><br/><b>Author:</b><br/><b>Version:</b><br/><b>Description:</b>"));
 #ifndef	Q_OS_MAC
 	l_moduleinfo->setSizePolicy(QSizePolicy(QSizePolicy::Expanding, QSizePolicy::Minimum));
-#endif
+#endif /* Q_OS_MAC */
 	l_moduleinfo->setWordWrap(true);
 
 	infoLayout->addWidget(l_moduleinfo);
+#endif /* Q_WS_HILDON */
 
 	// buttons
 	QWidget *bottom = new QWidget(center);
@@ -174,7 +178,9 @@ ModulesDialog::ModulesDialog(QWidget *parent)
 
 	centerLayout->addWidget(l_info);
 	centerLayout->addWidget(lv_modules);
+#ifndef Q_WS_HILDON
 	centerLayout->addWidget(vgb_info);
+#endif
 	centerLayout->addWidget(bottom);
 
 	QHBoxLayout *layout = new QHBoxLayout(this);
@@ -182,7 +188,9 @@ ModulesDialog::ModulesDialog(QWidget *parent)
 	layout->addWidget(center);
 
 	connect(pb_close, SIGNAL(clicked()), this, SLOT(close()));
+#ifndef Q_WS_HILDON
 	connect(lv_modules, SIGNAL(itemSelectionChanged()), this, SLOT(itemsChanging()));
+#endif
 	connect(lv_modules, SIGNAL(itemDoubleClicked(QTreeWidgetItem *, int)), this, SLOT(moduleAction(QTreeWidgetItem *)));
 
 	loadWindowGeometry(this, "General", "ModulesDialogGeometry", 0, 50, 600, 620);
@@ -412,6 +420,9 @@ ModulesManager::ModulesManager() : QObject(NULL, "modules_manager"),
 		if (!moduleIsActive(i))
 			activateModule(i);
 
+	if (kadu->safeMode())
+		return;
+
 	foreach(const QString &i, installed_list)
 	{
 		if (!moduleIsActive(i))
@@ -679,6 +690,19 @@ void ModulesManager::saveLoadedModules()
 	config_file.sync();
 }
 
+QString ModulesManager::modulesUsing(const QString &module_name)
+{
+	ModuleInfo info;
+	QStringList moduleList = loadedModules();
+	QString modules = "";
+
+	foreach(const QString &moduleName, moduleList)
+	if (moduleInfo(moduleName, info))
+		if (info.depends.contains(module_name))
+			modules += moduleName + " ";
+	return modules;
+}
+
 bool ModulesManager::conflictsWithLoaded(const QString &module_name, const ModuleInfo& module_info) const
 {
 	kdebugf();
@@ -811,7 +835,7 @@ bool ModulesManager::deactivateModule(const QString& module_name, bool force)
 
 	if (m.usage_counter>0 && !force)
 	{
-		MessageBox::msg(tr("Module %1 cannot be deactivated because it is used now").arg(module_name));
+		MessageBox::msg(tr("Module %1 cannot be deactivated because it is used by:\n%2").arg(module_name).arg(modulesUsing(module_name)));
 		kdebugf2();
 		return false;
 	}
