@@ -123,7 +123,7 @@ void PendingMsgs::writeToFile()
 		t = i.msg.length();
 		f.writeBlock((char*)&t,sizeof(int));
 		// message content
-		QString cmsg = codec_latin2->fromUnicode(i.msg);
+		QString cmsg = codec_utf8->fromUnicode(i.msg);
 		f.writeBlock(cmsg, cmsg.length());
 		// message class
 		f.writeBlock((char*)&i.msgclass,sizeof(int));
@@ -157,7 +157,8 @@ bool PendingMsgs::loadFromFile()
 
 		// reading uins, first number of
 		int uins_size;
-		if (f.readBlock((char*)&uins_size, sizeof(int)) <= 0) {
+		if ((f.readBlock((char*)&uins_size, sizeof(int)) <= 0) || (uins_size <= 0)) {
+			kdebugmf(KDEBUG_WARNING, "File kadu.msgs is corrupted\n");
 			--msgs_size;
 			return false;
 		}
@@ -188,7 +189,7 @@ bool PendingMsgs::loadFromFile()
 			return false;
 		}
 		buf[msg_size] = 0;
-		e.msg = codec_latin2->toUnicode(buf);
+		e.msg = codec_utf8->toUnicode(buf);
 		delete[] buf;
 
 		// message class
