@@ -1,50 +1,40 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="1.1" language="pl_PL">
+<!DOCTYPE TS><TS>
 <defaultcodec></defaultcodec>
 <context>
     <name>Wizard</name>
     <message>
-        <location filename="../wizard.cpp" line="90"/>
         <source>Kadu Wizard</source>
         <translation>Kreator konfiguracji Kadu</translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="331"/>
         <source>I have a number</source>
         <translation>Mam już numer</translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="335"/>
         <source>Gadu-gadu number</source>
         <translation>Numer GG</translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="340"/>
         <source>Gadu-gadu password</source>
         <translation>Hasło</translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="346"/>
         <source>Import contacts</source>
         <translation>Zaimportuj kontakty</translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="365"/>
         <source>Your e-mail address</source>
         <translation>Adres e-mail</translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="457"/>
         <source>Choose your browser</source>
         <translation>Wybierz przeglądarkę</translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="647"/>
         <source>Sound</source>
         <translation>Dźwięk</translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="221"/>
         <source>Error data typed in required fields.
 
 Passwords typed in both fields (&quot;New password&quot; and &quot;Retype new password&quot;) should be the same!</source>
@@ -53,49 +43,24 @@ Passwords typed in both fields (&quot;New password&quot; and &quot;Retype new pa
 Hasło powinno w obu polach być takie same!</translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="274"/>
         <source>An error has occured while registration. Please try again later.</source>
         <translation>Wystąpił błąd podczas rejestracji. Spróbuj ponownie później.</translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="99"/>
-        <source>Finish</source>
-        <translation>Zakończ</translation>
-    </message>
-    <message>
-        <location filename="../wizard.cpp" line="102"/>
-        <source>Next &gt;</source>
-        <translation>Dalej &gt;</translation>
-    </message>
-    <message>
-        <location filename="../wizard.cpp" line="105"/>
-        <source>&lt; Back</source>
-        <translation>&lt; Wstecz</translation>
-    </message>
-    <message>
-        <location filename="../wizard.cpp" line="107"/>
-        <source>Cancel</source>
-        <translation>Anuluj</translation>
-    </message>
-    <message>
-        <location filename="../wizard.cpp" line="310"/>
         <source>User list wasn&apos;t imported because of some error</source>
         <translation>Lista kontaktów nie została zaimportowana z powodu błędu</translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="370"/>
         <source>Register</source>
         <translation>Rejestruj</translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="266"/>
         <source>Registration was successful.
 You UIN is: </source>
         <translation>Rejestracja zakończona sukcesem.
 Twój nr GG: </translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="266"/>
         <source>
 Account configuration was saved.
 Press Ok to continue</source>
@@ -104,167 +69,118 @@ Konfiguracja konta została zapisana.
 Naciśnij Ok by kontynuować</translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="227"/>
         <source>Please fill out all fields</source>
         <translation>Proszę wypełnić wszystkie pola</translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="233"/>
         <source>Email address you have entered is not valid</source>
         <translation>Podany adres e-mail jest nie prawidłowy</translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="323"/>
-        <source>Account</source>
-        <translation>Konto</translation>
-    </message>
-    <message>
-        <location filename="../wizard.cpp" line="350"/>
         <source>I don&apos;t have a number</source>
         <translation>Nie posiadam numeru</translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="353"/>
         <source>New password</source>
         <translation>Nowe hasło</translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="359"/>
         <source>Retype password</source>
         <translation>Powtórz hasło</translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="449"/>
-        <source>WWW browser</source>
-        <translation>Przeglądarka WWW</translation>
-    </message>
-    <message>
-        <location filename="../wizard.cpp" line="486"/>
         <source>Specify path</source>
         <translation>Specyficzna ścieżka</translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="460"/>
         <source>Konqueror</source>
         <translation>Konqueror</translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="461"/>
         <source>Opera</source>
         <translation>Opera</translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="464"/>
         <source>Mozilla</source>
         <translation>Mozilla</translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="465"/>
         <source>Mozilla Firefox</source>
         <translation>Mozilla Firefox</translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="466"/>
         <source>Dillo</source>
         <translation>Dillo</translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="467"/>
         <source>Galeon</source>
         <translation>Galeon</translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="468"/>
         <source>Safari</source>
         <translation>Safari</translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="472"/>
         <source>Custom browser</source>
         <translation>Własny wybór</translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="476"/>
-        <source>e-mail client</source>
-        <translation>Klient poczty</translation>
-    </message>
-    <message>
-        <location filename="../wizard.cpp" line="484"/>
         <source>Choose your e-mail client</source>
         <translation>Wybierz swojego klienta e-mail</translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="487"/>
         <source>KMail</source>
         <translation>KMail</translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="488"/>
         <source>Thunderbird</source>
         <translation>Thunderbird</translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="489"/>
         <source>SeaMonkey</source>
         <translation>SeaMonkey</translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="490"/>
         <source>Evolution</source>
         <translation>Evolution</translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="494"/>
         <source>Custom e-mail client</source>
         <translation>Własny wybór</translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="502"/>
         <source>Applications</source>
         <translation>Aplikacje</translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="505"/>
         <source>&lt;p&gt;Please setup Kadu for working with your favourite WWW browser and email program.&lt;/p&gt;&lt;p&gt;Kadu will use these for opening various links from messages and user&apos;s descriptions&lt;/p&gt;</source>
         <translation>&lt;p&gt;Proszę ustawić programy do współpracy Kadu ze stronami WWW i pocztą e-mail.&lt;/p&gt;&lt;p&gt;Kadu będzie ich używac do otwierania linków z wiadomości i opisów użytkowników&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="582"/>
-        <source>Sound driver</source>
-        <translation type="obsolete">System dźwięku</translation>
-    </message>
-    <message>
-        <location filename="../wizard.cpp" line="599"/>
         <source>Test sound</source>
         <translation>Test dźwięku</translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="652"/>
         <source>&lt;p&gt;Please select your sound driver for sound notifications. If you don&apos;t want sound notifications, use None driver.&lt;/p&gt;&lt;p&gt;If you don&apos;t know which driver to use, just check every ony with Test sound button.Don&apos;t forget to unmute your system before!&lt;/p&gt;</source>
         <translation>&lt;p&gt;Proszę wybrać odpowiedni system dźwięku dla powiadomień sygnałami dźwiękowymi. Jeżeli nie chcesz być powiadamiany dźwiękiem wybierz &quot;None&quot;.&lt;/p&gt;Jeśli nie wiesz jaki system dźwięku jest przez ciebie używany, sprawdź po kolei wszystkie testując przyciskiem &quot;Test dźwięku&quot;. Nie zapomnij wcześniej ustawić mikser na odpowiednią siłę głosu!&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="400"/>
         <source>&lt;h3&gt;Welcome in Kadu&lt;/h3&gt;&lt;h4&gt;the Gadu-gadu network client for *nix and MacOS X.&lt;/h4&gt;&lt;p&gt;This is first time you launch Kadu. This wizard will help you to configure the basic settings of Kadu. If you are experienced Kadu user you may omit the wizard by clicking Cancel.&lt;/p&gt;&lt;p&gt;Please enter your account data. If you don&apos;t have one, you can create new here.&lt;/p&gt;&lt;p&gt;E-mail address is needed when you want to recover lost password to account&lt;/p&gt;</source>
         <translation>&lt;h3&gt;Witamy w Kadu&lt;/h3&gt;&lt;h4&gt;kliencie sieci Gadu-Gadu dla systemów *nix i MacOS X.&lt;/h4&gt;&lt;p&gt;Uruchomiłeś Kadu po raz pierwszy.Ten kreator pomoże ci ustawić podstawową konfigurację programu. Jeśli jesteś doświadczonym użytkownikiem możesz go pominąć klikając na przycisk &quot;Anuluj&quot;.&lt;/p&gt;&lt;p&gt;Proszę wprowadzić swoje dane konta GG. Jeśli go nie posiadasz możesz je teraz utworzyć.&lt;/p&gt;&lt;p&gt;Adres e-mail jest potrzebny do przypomnienia zapomnianego hasła&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="395"/>
         <source>Gadu-gadu account</source>
         <translation>Konto Gadu-Gadu</translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="595"/>
         <source>Sound system</source>
         <translation>System dźwiękowy</translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="462"/>
         <source>Opera (new tab)</source>
         <translation>Opera (nowa karta)</translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="530"/>
         <source>Not found</source>
         <translation>Nie znaleziono</translation>
     </message>
@@ -272,12 +188,10 @@ Naciśnij Ok by kontynuować</translation>
 <context>
     <name>WizardStarter</name>
     <message>
-        <location filename="../wizard.cpp" line="62"/>
         <source>Configuration Wizard</source>
         <translation>Kreator konfiguracji</translation>
     </message>
     <message>
-        <location filename="../wizard.cpp" line="203"/>
         <source>User list couldn&apos;t be imported</source>
         <translation>Lista kontaktów nie została zaimportowana</translation>
     </message>
