@@ -1,54 +1,43 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="1.1" language="pl_PL">
+<!DOCTYPE TS><TS>
 <context>
     <name>@default</name>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="4"/>
         <source>Kadu</source>
         <translation>Kadu</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="7"/>
         <source>Tray</source>
         <translation>Tacka systemowa</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="10"/>
         <source>Desktop docking</source>
         <translation>Dokowanie na pulpicie</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="13"/>
         <source>Horizontal position</source>
         <translation>Pozycja pozioma</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="16"/>
         <source>Vertical position</source>
         <translation>Pozycja pionowa</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="19"/>
         <source>Transparent</source>
         <translation>Przezroczystość</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="22"/>
         <source>Background color</source>
         <translation>Kolor tła</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="25"/>
         <source>Enable Move entry in docklet&apos;s menu</source>
         <translation>Pokaż element &apos;Przesuń&apos; w menu ikony</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="28"/>
         <source>Move</source>
         <translation>Przesuń</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="30"/>
         <source>Enable icon moving on desktop. After pressing move cursor over docking icon and then move. Press any mouse key when the icon is in right place.</source>
         <translation>Zezwól na przesuwanie ikony po pulpicie. Po wciśnięciu przycisku myszy zacznj przesuwać kursor. Naciśnij przycisk myszy gdy ikona znajdzie się na pożądanej pozycji.</translation>
     </message>
@@ -56,7 +45,6 @@
 <context>
     <name>DesktopDock</name>
     <message>
-        <location filename="../desktopdock.cpp" line="241"/>
         <source>Move</source>
         <translation>Przesuń</translation>
     </message>
