@@ -1,8 +1,8 @@
 #ifndef KADU_DSP_SOUND_H
 #define KADU_DSP_SOUND_H
-#include <qobject.h>
-#include <qstring.h>
-#include <qstringlist.h>
+#include <QtCore/QObject>
+#include <QtCore/QString>
+#include <QtCore/QStringList>
 #include "../sound/sound.h"
 
 /**
@@ -19,10 +19,10 @@ class OSSPlayerSlots : public QObject
 	void createDefaultConfiguration();
 
 public slots:
-	void openDevice(SoundDeviceType type, int sample_rate, int channels, SoundDevice& device);
+	void openDevice(SoundDeviceType type, int sample_rate, int channels, SoundDevice* device);
 	void closeDevice(SoundDevice device);
-	void playSample(SoundDevice device, const int16_t* data, int length, bool& result);
-	void recordSample(SoundDevice device, int16_t* data, int length, bool& result);		
+	void playSample(SoundDevice device, const int16_t* data, int length, bool* result);
+	void recordSample(SoundDevice device, int16_t* data, int length, bool* result);
 	void setFlushingEnabled(SoundDevice device, bool enabled);
 
 public:
