@@ -57,7 +57,12 @@ protected:
 	void showHistoryEntries(int from, int count);
 	void setDateListViewText(const QDateTime &datetime);
 	void searchHistory();
+	bool searchCurrentPage();
+	bool openFirstPage();
+	int openNextPage();
+	bool searchInHistory(int index);
 	static const QString &gaduStatus2symbol(unsigned int status);
+	QString searchString();
 	void closeEvent(QCloseEvent *e);
 
 	QTreeWidget *uinsTreeWidget;
