@@ -118,6 +118,18 @@
         <source>Rebuild index</source>
         <translation>Przebuduj indeks</translation>
     </message>
+    <message>
+        <source>Do Not Disturb</source>
+        <translation>Nie przeszkadzać</translation>
+    </message>
+    <message>
+        <source>Talk With Me</source>
+        <translation>Porozmawiaj ze mną</translation>
+    </message>
+    <message>
+        <source>No more matches found</source>
+        <translation>Nie znaleziono więcej dopasowań</translation>
+    </message>
 </context>
 <context>
     <name>HistoryManager</name>
