@@ -195,7 +195,7 @@ SoundManager::SoundManager(bool firstLoad, const QString& name, const QString& c
 	sound_manager = this;
 	sound_slots = new SoundSlots(firstLoad, this);
 
-	themes->setPaths(QStringList::split(QRegExp("(;|:)"), config_file.readEntry("Sounds", "SoundPaths")));
+	themes->setPaths(QStringList::split(QRegExp("(;|&)"), config_file.readEntry("Sounds", "SoundPaths")));
 
 	QStringList soundThemes = themes->themes();
 	QString soundTheme = config_file.readEntry("Sounds", "SoundTheme");
@@ -333,6 +333,8 @@ void SoundManager::createDefaultConfiguration()
 	config_file.addVariable("Notify", "NewMessage_Sound", true);
 	config_file.addVariable("Notify", "StatusChanged/ToOnline_Sound", true);
 	config_file.addVariable("Notify", "StatusChanged/ToBusy_Sound", true);
+	config_file.addVariable("Notify", "StatusChanged/ToTalkWithMe_Sound", true);
+	config_file.addVariable("Notify", "StatusChanged/ToDoNotDisturb_Sound", true);
 	config_file.addVariable("Notify", "FileTransfer/IncomingFile_Sound", true);
 
 	config_file.addVariable("Sounds", "PlaySound", true);
