@@ -1,69 +1,55 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="1.1" language="pl">
+<!DOCTYPE TS><TS>
 <context>
     <name>@default</name>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="8"/>
         <source>Sound</source>
         <translation>Dźwięk</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="4"/>
         <source>Notifications</source>
         <translation>Powiadomienia</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="11"/>
         <source>General</source>
         <translation>Ogólne</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="14"/>
         <source>Use sounds</source>
         <translation>Używaj dźwięków</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="18"/>
         <source>Theme</source>
         <translation>Zestaw</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="21"/>
         <source>Sound theme</source>
         <translation>Zestaw dźwięków</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="24"/>
         <source>Sound paths</source>
         <translation>Ścieżki do zestawów</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="34"/>
         <source>Volume</source>
         <translation>Głośność</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="31"/>
         <source>Enable volume control (player must support it)</source>
         <translation>Włącz kontrolę głośności (musi być wspierana przez odtwarzacz)</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="38"/>
         <source>Samples</source>
         <translation>Testy</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="41"/>
         <source>Test sample playing</source>
         <translation>Test odtwarzania</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="44"/>
         <source>Test sample recording</source>
         <translation>Test nagrywania</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="47"/>
         <source>Test full duplex</source>
         <translation>Test pełnego dupleksu (odtwarzania i nagrywanie)</translation>
     </message>
@@ -71,12 +57,14 @@
 <context>
     <name>SoundConfigurationWidget</name>
     <message>
-        <location filename="../sound_slots.cpp" line="33"/>
+        <source>Choose &apos;Custom&apos; theme in &apos;Sound&apos; page to change sound file</source>
+        <translation>Wybierz zestaw &apos;Własne&apos; na stronie &apos;Dźwięk&apos; aby zmieniać plik dźwiękowy</translation>
+    </message>
+    <message>
         <source>Test</source>
         <translation>Test</translation>
     </message>
     <message>
-        <location filename="../sound_slots.cpp" line="37"/>
         <source>Sound file</source>
         <translation>Plik dźwiękowy</translation>
     </message>
@@ -84,7 +72,6 @@
 <context>
     <name>SoundManager</name>
     <message>
-        <location filename="../sound.cpp" line="280"/>
         <source>Custom</source>
         <translation>Własne</translation>
     </message>
@@ -92,54 +79,44 @@
 <context>
     <name>SoundSlots</name>
     <message>
-        <location filename="../sound_slots.cpp" line="90"/>
         <source>Unmute sounds</source>
         <translation>Przywróć dźwięki</translation>
     </message>
     <message>
-        <location filename="../sound_slots.cpp" line="89"/>
         <source>Mute sounds</source>
         <translation>Wyłącz dźwięki</translation>
     </message>
     <message>
-        <location filename="../sound_slots.cpp" line="145"/>
         <source>Opening test sample file failed.</source>
         <translation>Otwarcie pliku testowego nieudane.</translation>
     </message>
     <message>
-        <location filename="../sound_slots.cpp" line="152"/>
         <source>Reading test sample file failed.</source>
         <translation>Czytanie pliku testowego nieudane.</translation>
     </message>
     <message>
-        <location filename="../sound_slots.cpp" line="273"/>
         <source>Opening sound device failed.</source>
         <translation>Otwarcie urządzenia dźwięku nieudane.</translation>
     </message>
     <message>
-        <location filename="../sound_slots.cpp" line="173"/>
         <source>Testing sample playing. You should hear some sound now.</source>
         <translation>Test odtwarzania dźwięku. Powinien on być teraz słyszalny.</translation>
     </message>
     <message>
-        <location filename="../sound_slots.cpp" line="212"/>
         <source>Testing sample recording. Please talk now (3 seconds).</source>
         <translation>Test nagrywania. Proszę mówić przez 3 sekundy.</translation>
     </message>
     <message>
-        <location filename="../sound_slots.cpp" line="240"/>
         <source>You should hear your recorded sample now.</source>
         <translation>Nagrany dźwięk powinien być teraz słyszalny.</translation>
     </message>
     <message>
-        <location filename="../sound_slots.cpp" line="281"/>
         <source>Testing fullduplex. Please talk now.
 You should here it with one second delay.</source>
         <translation>Test full dupleksu. Proszę teraz mówić. Dźwięk powinien
 być słyszalny z 1 sekundowym opóźnieniem.</translation>
     </message>
     <message>
-        <location filename="../sound_slots.cpp" line="233"/>
         <source>Cannot open sound device for playing!</source>
         <translation>Nie mogę otworzyć urządzenia dźwiękowego do odtwarzania!</translation>
     </message>
