@@ -1,54 +1,43 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS><TS version="1.1">
+<!DOCTYPE TS><TS>
 <context>
     <name>@default</name>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="4"/>
         <source>Account</source>
         <translation>Conto</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="7"/>
         <source>File transfers and voice chats</source>
         <translation>File trasferimento e Chat a voce</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="10"/>
         <source>Voice chats</source>
         <translation>Chat a voce</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="13"/>
         <source>Faster compression algorithm (degrades quality)</source>
         <translation>Compressione veloce (degrada qualità)</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="16"/>
         <source>Cut-off optimization (faster but degrades quality)</source>
         <translation>Ottimizzazione Cut-off (più veloce ma degrada qualità)</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="19"/>
         <source>Test GSM Encoding</source>
         <translation>Test Codifica GSM</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="26"/>
         <source>Shortcuts</source>
         <translation>Scorciatoie</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="29"/>
         <source>General</source>
         <translation>Generale</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="35"/>
         <source>Voice chat</source>
         <translation>Chat a voce</translation>
     </message>
     <message>
-        <location filename="../.configuration-ui-translations.cpp" line="32"/>
         <source>Sending files and voice chats</source>
         <translation>Manda un file e Chat a voce</translation>
     </message>
@@ -56,12 +45,10 @@
 <context>
     <name>VoiceChatDialog</name>
     <message>
-        <location filename="../voice.cpp" line="61"/>
         <source>Voice chat</source>
         <translation>Chat a voce</translation>
     </message>
     <message>
-        <location filename="../voice.cpp" line="64"/>
         <source>&amp;Stop</source>
         <translation>&amp;Stop</translation>
     </message>
@@ -69,32 +56,26 @@
 <context>
     <name>VoiceManager</name>
     <message>
-        <location filename="../voice.cpp" line="721"/>
         <source>Voice chat</source>
         <translation>Chat a voce</translation>
     </message>
     <message>
-        <location filename="../voice.cpp" line="684"/>
         <source>User %1 wants to talk with you. Do you accept it?</source>
         <translation>Contatto %1 deisdera parlare con te. Accetti ?</translation>
     </message>
     <message>
-        <location filename="../voice.cpp" line="435"/>
         <source>Opening DSP Encoder failed.</source>
         <translation>Apertura Encoder DSP fallita.</translation>
     </message>
     <message>
-        <location filename="../voice.cpp" line="449"/>
         <source>Opening sound device failed.</source>
         <translation>Apertura dispositivo audio fallita.</translation>
     </message>
     <message>
-        <location filename="../voice.cpp" line="462"/>
         <source>Testing GSM Encoding. Please talk now (3 seconds).</source>
         <translation>Test codifica GSM. Prego di parlare per 3 secondi.</translation>
     </message>
     <message>
-        <location filename="../voice.cpp" line="484"/>
         <source>You should hear your recorded sample now.</source>
         <translation>Audio registrato dovrebbe farsi sentire.</translation>
     </message>
